---
permalink: /manual/languages
fbcontact: true
---

# Sprachen

Der KMUHelper selbst ist aktuell nur in Deutsch verfügbar und eine Übersetzung ist vorerst nicht geplant. Jedoch können die Rechnungen in Deutsch, Französisch, Italienisch und Englisch gedruckt werden. Dabei wird immer die beim Kunden eingestellte Sprache verwendet.

Um auch Produkte und Mengenbezeichnungen zu übersetzen, wird der gleiche Syntax wie beim Wordpress Plugin `qTranslate-X` verwendet.

Beispiel: `[:de]Stück[:fr]Pièce[:it]Pezzo[:en]Piece[:]`

Die Unterstützung für mehrere Sprachen existiert bisher nur bei folgenden Feldern:

- Produkt: Name
- Produkt: Beschreibung
- Produkt: Mengenbezeichnung
- Kosten: Name

## Zurück

[Zurück zum Handbuch](./README.md)
